%This program produces Figure 8 in Xiao, J., Equilibrium Analysis of the All-Pay Contest 
% with Two Nonidentical Prizes: Complete Results. 

clear all
close all
clc

%Smaller scale simulations. It runs for about 4 minutes. The resulting figure is not as smooth as the full scale one.
n=300;%number of grids for integration;
m=100;%number of grids for marginal costs
m_v=50; %number of grids for prize values

% % Full scale simulation, it runs for about 5 hours. The resulting figure
% % is "Figure 8.jpg". You may need to increase the Java heap memory for
% % Matlab.
% 
% n=1000;%number of grids for calculation;
% m=400; %number of grids for marginal costs
% m_v=100; %number of grids for prize values

%Produce a matrix of different values of vector (c1,c2,c3) such that c1<c2<c3:
l_c=1/m; %smallest unit in the space of c1,c2,c3;
c1=l_c;
c2=l_c;
c3=1-c1-c2;
C=[0,0,0];
while c1<=1/3;
    while c2<=c3;
          C=[C;[c1,c2,c3]];
          c2=c2+l_c;
          c3=1-c1-c2;
    end;
    c1=c1+l_c;
    c2=c1;
    c3=1-c1-c2;
    if c3<c2;
        break;
    end;
end;
C=C(2:max(size(C)),:); %this is the matrix of prizes with a prize vector 
%in each row;

%For each vector of (c1,c2,c3),  Vstar records the optimal prize allocation
r_C=max(size(C)); %number of rows in V;
Vstar=zeros(r_C,1);
%tic
for i=1:r_C;
    c1=C(i,1);
    c2=C(i,2);
    c3=C(i,3);
    %showing (c1,c2,c3) the program is simulating:
    %[c1,c2,c3]
    Vstar(i)=optimalprize(c1,c2,c3,n,m_v); 
    %save('allcosts');
    %toc
end;

%Produce a matrix of different values of vector (c1,c2,c3) in the simplex
C_all=zeros(1,3);
for i=1:m-2;
    c1=l_c*i;
    for j=1:m-i-1;
        c2=l_c*j;
        c3=1-c1-c2;
        C_all=[C_all;[c1,c2,c3]];
    end;
end;
clear c1 c2 c3;
C_all=C_all(2:max(size(C_all)),:);

%Produce a matrix of optimal prize allocation for each vector (c1,c2,c3) in the simplex
Vstar_all=zeros(max(size(C_all)),1);
for i=1:max(size(C_all));
    %ranked the cost in the ith row:
    c=sort(C_all(i,:));
    for j=1:max(size(C));
      if (c(1)-C(j,1))^2<1/n^2;
      if (c(2)-C(j,2))^2<1/n^2;
      if (c(3)-C(j,3))^2<1/n^2;
          Vstar_all(i)=Vstar(j);
      end;
      end;
      end;
    end;
end;

C_all=C_all(find(Vstar_all),:);
Vstar_all=Vstar_all(find(Vstar_all));
%record the optimal prize for different costs:
optimalprize=[C_all,Vstar_all];


%Transform the vector (c1,c2,c3)into coordinates in the simplex
%Calculate three corners: 
A1=[0,3^(1/2)/3];
A2=[-1/2,-3^(1/2)/6];
A3=[1/2,-3^(1/2)/6]; 
% A prize vector (v1,v2,v3) such that 0<=vi<=1 and v1+v2+v3<=1 has coordinate (a1,a2)=v1*A1+v2*A2+v3*A3. 
%record the coordinates in the matrix coord:
coordcost=zeros(max(size(C_all)),3);
for i=1:max(size(C_all));
    c1=C_all(i,1);
    c2=C_all(i,2);
    c3=C_all(i,3);
    %calcualte the coordinates:
    X=c1*A1+c2*A2+c3*A3; %coordinates in the simplex
    coordcost(i,:)=[X,Vstar_all(i)];
end;
%Plot the optimal prizes in the simplex
X=coordcost(:,1);
Y=coordcost(:,2);
S=coordcost(:,3);
tri = delaunay(X,Y);
h = trisurf(tri, X, Y, S);
lighting phong
shading interp
axis([-1/2 1/2 -3^(1/2)/6 3^(1/2)/3 0 1]);
view(2)%view the 3d plot from above


