%Given prizes v1 and v2, marginal costs c1,c2,c3, this function calcultes uses prizes and costs to produce payoffs u and expected
%scores es in the equilibrium. 
function [ es u ] = outcome(v1,v2,v3,c1,c2,c3,n)%n is the number of grids for calculation
    
%Since the costs and prizes may not be ranked, we need to rank them first:
%1. record the orginal costs and prizes. 
C_original = [c1,c2,c3];
V_original = [v1,v2,v3];
%2. rename them to have decreasing prizes and increasing costs:
C = sort(C_original);
V = sort(V_original,'descend');
c1 = C(1); c2 = C(2); c3 = C(3);
v1 = V(1); v2 = V(2); v3 = V(3);

%all different prizes 
if v1>v2+1/n^2;
if v2>v3+1/n^2;
    
C = [c1,c2,c3];
V = [v1,v2,v3];

% %Suppose there are only two players 1 and 2:
% %the upper boundary of the support of player 1's mixed strategy is:
S1 = (v1-v3) / c2;

%the payoffs are 
u1=v1-c1*S1;
u2=v1-c2*S1;
G1_2=@(s)((1/(v1-v2))*(u2-v2+s*c2));
G2_2=@(s)((1/(v1-v2))*(u1-v2+s*c1));
% expected winning of 3 is 
W_3=@(G1,G2,s)(v1*G1*G2+v2*((1-G1)*G2+G1*(1-G2))+v3*((1-G1)*(1-G2)));
%lower support of G1_2 is (where G1_2 = 0)
S1_l=(v2-u2)/c2;

%set the grid for mixed strategies:
l=(S1-S1_l)/n; % %this gives us finer grid for small S1-S1_l

%create cdf record matrices:
S=zeros(n+1,1);
G1=zeros(n+1,1);
G2=zeros(n+1,1);
for i=1:n+1;
%     S(i) = (i-1)*l;
    S(i) = S1_l+(i-1)*l;
    G1(i) = G1_2(S(i));
    G2(i) = G2_2(S(i));
end;

%find upper support of G3, best response S3
[S3 u3 S3_index]=findBR(W_3, G1, G2, S, S1, S1_l, c3);

%solve strategies G1 G2 G3 
C = [c1,c2,c3];
[G1 G2 G3 S gaps3 u1 u2 u3]=solveG(v1, v2, v3, C, n);

%Expected effort/scorelevels
es = zeros(1,3);
u = zeros(3,1);
%put the effort in the same orignal order of costs:
for i=1:3;
    if C_original(i) == c1;
    es(i) = expeffort(G1, S);
    u(i) = u1;
    end;
    if C_original(i) == c2;
    es(i) = expeffort(G2, S);
    u(i) = u2;
    end;
    if C_original(i) == c3;
    es(i) = expeffort(G3, S);
    u(i) = u3;
    end;
end;
    
end;
end;

%all prizes are the same:
if v1<v2+1/n^2;
if v1>v2-1/n^2;
if v2<v3++1/n^2;
if v2>v3-1/n^2;
    
        u1=v3;
        u2=v3;
        u3=v3;
        es=zeros(1,3); 
        
        u = zeros(3,1);
        %put the effort in the same orignal order of costs:
        for i=1:3;
            if C_original(i) == c1;
               u(i) = u1;
            end;
            if C_original(i) == c2;
                u(i) = u2;
            end;
            if C_original(i) == c3;
                u(i) = u3;
            end;
        end;

end;
end;
end;
end;

%Lower two prizes are the same:
if v2<v3+1/n^2;
if v2>v3-1/n^2;
if v1>v2;
    
   C = [c1,c2,c3];
   V = [v1,v2,v3];

   % There are only two players 1 and 2:
   % %the upper boundary of the support of player 1's mixed strategy is:

   S1 = (v1-v3) / c2;

   %the payoffs are 
   u1=v1-c1*S1;
   u2=v1-c2*S1;
   u3=v3;
   G1_2=@(s)((1/(v1-v2))*(u2-v2+s*c2));
   G2_2=@(s)((1/(v1-v2))*(u1-v2+s*c1));
   
   l=S1/n; %unit for scores

   %create cdf record matrices:
   S=zeros(n+1,1);
   G1=zeros(n+1,1);
   G2=zeros(n+1,1);
   for i=1:n+1;
    S(i) = (i-1)*l;
    G1(i) = G1_2(S(i));
    G2(i) = G2_2(S(i));
   end;
   
    
   %Expected effort/scorelevels
   es = zeros(1,3);
   u = zeros(3,1);
   %put the effort and payoffs in the same orignal order of costs:
   for i=1:3;
      if C_original(i) == c1;
      es(i) = expeffort(G1, S);
      u(i) = u1;
      end;
      if C_original(i) == c2;
      es(i) = expeffort(G2, S);
      u(i) = u2;
      end;
      if C_original(i) == c3;
      es(i) = 0;
      end;
   end;
   
end;
end;
end;


% Top two prizes are the same
if v1>v2-1/n^2;
if v1<v2+1/n^2;
if v2>v3;
  
C = [c1,c2,c3];
V = [v1,v2,v3];

%All the players have the same upper support:
S1 = (v1-v3) / c3;

%the payoffs are 
u1=v1-c1*S1;
u2=v1-c2*S1;
u3=v3;

%set the grid for mixed strategies:
l=S1/n; %length of intervals

%create cdf record matrices:
S=zeros(n+1,1);
G1=zeros(n+1,1);
G2=zeros(n+1,1);
G3=zeros(n+1,1);
for i=1:n+1;
    S(i) = (i-1)*l;
end;

%find upper support of G3, best response S3
S3 = S1;
S3_index=n+1;

%solve system to get pseudo strategies G1 G2 G3 (pre-ironing)
[G1 G2 G3 S]=solveG2(v1,v2,v3, c1,c2,c3, n);

%Expected effort/scorelevels
es = zeros(1,3);

u = zeros(3,1);
%put the effort in the same orignal order of costs:
for i=1:3;
    if C_original(i) == c1;
    es(i) = expeffort(G1, S);
    u(i) = u1;
    end;
    if C_original(i) == c2;
    es(i) = expeffort(G2, S);
    u(i) = u2;
    end;
    if C_original(i) == c3;
    es(i) = expeffort(G3, S);
    u(i) = u3;
    end;
end;
    
end;
end;
end;
    



