%This program constructs the mixed strategies in the unique equilibrium in
%contests with three players and two prizes. 

clear all
close all
clc

%Marginal costs and prizes
c1 = 4; c2 = 6; c3 =  7; v1 = 4; v2 = 1; v3 = 0; %This is for Example 2.
%Alternative values:
% c1 = 1; c2 = 4; c3 =  7; v1 = 4; v2 = 3; v3 = 0; %This is for Example 1.

%set the parameter of precision
n=1000; %number of grids

%There are several different cases:

%First,
if v1>v2;
if v2>v3;
    
C = [c1,c2,c3];
V = [v1,v2,v3];

%construct equilibrium strategies G1 G2 G3 given the prizes and costs
[G1 G2 G3 S gaps3 u1 u2 u3]=solveG(v1, v2, v3, C, n);

%calculate the expected performance
es = zeros(1,3);
es(1) = expeffort(G1, S);
es(2) = expeffort(G2, S);
es(3) = expeffort(G3, S);

display('Equilibrium Payoffs are [u1,u2,u3]=')
[u1,u2,u3]
display('Expected performance levels are [es1,es2,es3]=')
[es(1),es(2),es(3)]
    
end;
end;

%Second, all prizes are the same:
if v1==v2;
if v2==v3;
        u1=v3;
        u2=v3;
        u3=v3;
        es=zeros(1,3); 
        
        display('Equilibrium Payoffs are [u1,u2,u3]=')
        [u1,u2,u3]
        display('Expected score levels are [es1,es2,es3]=')
        [es(1),es(2),es(3)]
end;
end;

%Third, the lower two prizes are the same:
if v2==v3;
if v1>v2;
    
   C = [c1,c2,c3];
   V = [v1,v2,v3];

   %If there are only two players 1 and 2, the highest score in the support
   %of player 1's strategy is:

   S1 = (v1-v3) / c2;

   %the payoffs are 
   u1=v1-c1*S1;
   u2=v1-c2*S1;
   u3=v3;
   G1_2=@(s)((1/(v1-v2))*(u2-v2+s*c2));
   G2_2=@(s)((1/(v1-v2))*(u1-v2+s*c1));

   l=S1/n; %unit of score

   %create matrices for CDF's:
   S=zeros(n+1,1);
   G1=zeros(n+1,1);
   G2=zeros(n+1,1);
   for i=1:n+1;
    S(i) = (i-1)*l;
    G1(i) = G1_2(S(i));
    G2(i) = G2_2(S(i));
   end;
   
   figure(9);
%     dimension of S:
    S_dim=max(size(S));
    plot(S,G1,'g');
    hold on;
    plot(S,G2,'b')
    hold off;
%     axis([0 S1 -0.1 1.1]);
    axis([0 max(S) -0.1 1.1]);
    title('Equilibrium Strategies')
    
   %Expected performance
   es = zeros(1,3);
   es(1) = expeffort(G1, S);
   es(2) = expeffort(G2, S);
   es(3) = 0;
        
   display('Equilibrium Payoffs are [u1,u2,u3]=')
   [u1,u2,u3]
   display('Expected score levels are [es1,es2,es3]=')
   [es(1),es(2),es(3)]
   
end;
end;


%Fourth, the top two prizes are the same
if v1==v2;
if v2>v3;
  
C = [c1,c2,c3];
V = [v1,v2,v3];

%All the players have the same upper support:
S1 = (v1-v3) / c3;

%the payoffs are 
u1=v1-c1*S1;
u2=v1-c2*S1;
u3=v3;

l=S1/n; %unit for score

%Matrices for CDF's:
S=zeros(n+1,1);
G1=zeros(n+1,1);
G2=zeros(n+1,1);
G3=zeros(n+1,1);
for i=1:n+1;
    S(i) = (i-1)*l;
end;

%find the highest score in the support of G3:
S3 = S1;
S3_index=n+1;

%solve system to get strategies G1 G2 G3 
[G1 G2 G3 S]=solveG2(v1,v2,v3, c1,c2,c3, n);

%Expected effort/scorelevels
es = zeros(1,3);
es(1) = expeffort(G1, S);
es(2) = expeffort(G2, S);
es(3) = expeffort(G3, S);

    display('Equilibrium Payoffs are [u1,u2,u3]=')
    [u1,u2,u3]
    display('Expected score levels are [es1,es2,es3]=')
    [es(1),es(2),es(3)]
    
end;
end;
    



