%Using Proposition 2, this function gives the equilibrium payoffs u1, u2,
%u3 and delta, which is the difference between the highest score in G1's support and
%the highest score in G3's support.

function [u1 u2 u3 delta]=payoffs(v1, v2, v3, c1,c2,c3,n)

C = [c1,c2,c3];
V = [v1,v2,v3];

%Consider a contest with the top two players and two prizes
S1 = (v1-v2) / c2;

%The payoffs in the two-player contest are 
u1_2=v1-c1*S1;
u2_2=v1-c2*S1;
%The strategies in the two-player contest are
G1_2=@(s)((1/(v1-v2))*(u2_2-v2+s*c2));
G2_2=@(s)((1/(v1-v2))*(u1_2-v2+s*c1));

%Given players 1 and 2's strategies, player 3's expected winnings at s is 
W_3=@(G1,G2,s)(v1*G1*G2+v2*((1-G1)*G2+G1*(1-G2))+v3*((1-G1)*(1-G2)));
%lower support of G1_2 is (where G1_2 = 0)
S1_l=(v2-u2_2)/c2;

l=(S1-S1_l)/n; % %this is the unit for scores

%create cdf recording matrices:
S=zeros(n+1,1);
G1=zeros(n+1,1);
G2=zeros(n+1,1);
for i=1:n+1;
%     S(i) = (i-1)*l;
    S(i) = S1_l+(i-1)*l;
    G1(i) = G1_2(S(i));
    G2(i) = G2_2(S(i));
end;

%find 3's best response S3 against G1_2,G2_2. The corresponding maximum is
%u3_hat in (1). 
[S3 u3_hat S3_index]=findBR(W_3, G1, G2, S, S1, S1_l, c3);

%Equilibrium payoffs (from Proposition 2)
u1=u1_2-c1*u3_hat/c3;
u2=u2_2-c2*u3_hat/c3;
u3=v3;
delta=S1-S3;

end